@@ -7,11 +7,10 @@ import logging
 
 from datetime import datetime, timezone
 
-log = logging.getLogger('GremlinAPI.client')
+log = logging.getLogger("GremlinAPI.client")
 
 
 class GremlinAPIConfig(object):
-
     def __init__(self):
         self._api_key = None
         self._base_uri = None
@@ -159,4 +158,4 @@ class GremlinAPIConfig(object):
         Primarily used by the login function
         :return: bool
         """
-        return datetime.now(timezone.utc) >= cls.bearer_expires
\ No newline at end of file
+        return datetime.now(timezone.utc) >= cls.bearer_expires
