@@ -10,24 +10,22 @@ from gremlinapi.exceptions import (
     ProxyError,
     ClientError,
     HTTPTimeout,
-    HTTPError
+    HTTPError,
 )
 
 from gremlinapi.gremlinapi import GremlinAPI
 from gremlinapi.http_clients import get_gremlin_httpclient
 
 
-log = logging.getLogger('GremlinAPI.client')
+log = logging.getLogger("GremlinAPI.client")
 
 
 class GremlinAPIContainers(GremlinAPI):
-
     @classmethod
-    @register_cli_action('list_containers', ('',), ('teamId'))
+    @register_cli_action("list_containers", ("",), ("teamId"))
     def list_containers(cls, https_client=get_gremlin_httpclient(), **kwargs):
-        method = 'GET'
-        endpoint = cls._optional_team_endpoint(f'/containers', **kwargs)
-        payload = cls._payload(**{'headers': https_client.header()})
+        method = "GET"
+        endpoint = cls._optional_team_endpoint(f"/containers", **kwargs)
+        payload = cls._payload(**{"headers": https_client.header()})
         (resp, body) = https_client.api_call(method, endpoint, **payload)
         return body
-
