@@ -10,24 +10,22 @@ from gremlinapi.exceptions import (
     ProxyError,
     ClientError,
     HTTPTimeout,
-    HTTPError
+    HTTPError,
 )
 
 from gremlinapi.gremlinapi import GremlinAPI
 from gremlinapi.http_clients import get_gremlin_httpclient
 
 
-log = logging.getLogger('GremlinAPI.client')
+log = logging.getLogger("GremlinAPI.client")
 
 
 class GremlinAPIMetadata(GremlinAPI):
-
     @classmethod
-    @register_cli_action('get_metadata', ('',), ('teamId',))
+    @register_cli_action("get_metadata", ("",), ("teamId",))
     def get_metadata(cls, https_client=get_gremlin_httpclient(), *args, **kwargs):
-        method = 'GET'
-        endpoint = cls._optional_team_endpoint('/metadata', **kwargs)
-        payload = cls._payload(**{'headers': https_client.header()})
+        method = "GET"
+        endpoint = cls._optional_team_endpoint("/metadata", **kwargs)
+        payload = cls._payload(**{"headers": https_client.header()})
         (resp, body) = https_client.api_call(method, endpoint, **payload)
         return body
-
