@@ -10,33 +10,31 @@ from gremlinapi.exceptions import (
     ProxyError,
     ClientError,
     HTTPTimeout,
-    HTTPError
+    HTTPError,
 )
 
 from gremlinapi.gremlinapi import GremlinAPI
 from gremlinapi.http_clients import get_gremlin_httpclient
 
 
-log = logging.getLogger('GremlinAPI.client')
+log = logging.getLogger("GremlinAPI.client")
 
 
 class GremlinAPIProviders(GremlinAPI):
-
     @classmethod
-    @register_cli_action('list_providers', ('',), ('',))
+    @register_cli_action("list_providers", ("",), ("",))
     def list_providers(cls, https_client=get_gremlin_httpclient(), *args, **kwargs):
-        method = 'GET'
-        endpoint = '/providers'
-        payload = cls._payload(**{'headers': https_client.header()})
+        method = "GET"
+        endpoint = "/providers"
+        payload = cls._payload(**{"headers": https_client.header()})
         (resp, body) = https_client.api_call(method, endpoint, **payload)
         return body
 
     @classmethod
-    @register_cli_action('list_aws_services', ('',), ('',))
+    @register_cli_action("list_aws_services", ("",), ("",))
     def list_aws_services(cls, https_client=get_gremlin_httpclient(), *args, **kwargs):
-        method = 'GET'
-        endpoint = '/providers/aws'
-        payload = cls._payload(**{'headers': https_client.header()})
+        method = "GET"
+        endpoint = "/providers/aws"
+        payload = cls._payload(**{"headers": https_client.header()})
         (resp, body) = https_client.api_call(method, endpoint, **payload)
         return body
-
