@@ -5,10 +5,10 @@
 import logging
 
 
-log = logging.getLogger('GremlinAPI.client')
+log = logging.getLogger("GremlinAPI.client")
 
-_version = '0.9.2'
+_version = "0.9.7"
 
 
 def get_version():
-    return _version
\ No newline at end of file
+    return _version
